clear
close all
clc

n = 200;

% defining parametres
g = 9.81; %[m/s^2]
roL = 958.38; %[kg/m^3]
roG = 0.947; %[kg/m^3]
r_j = [roL/roG 1]; r = r_j(1);
muG = 21.74e-6; %[Pa*s]
muL = 0.0002814; %[Pa*s]
m_j = [muL/muG 1]; m = m_j(1);
d_G = 0.002;
d_L = 0.001;
H = d_G + d_L;
dG = d_G/H;
delta = d_L/H;
d_j = [delta/dG 1]; d = d_j(1);
sigma = 0.001; %[N/m]
gammaL = 800; %[Pa/m]
gammaG = 800; %[Pa/m]
tau_i = (gammaG*muL*d_G^2 - gammaL*muG*d_L^2 + g*(d_L^2*muG*roL - d_G^2*muL*roG))/(2*d_L*muG + 2*d_G*muL);

% normalization parameters
u_g = sqrt(g*H);  %% characteristic gravitational velocity
u_p = sqrt(H*gammaG/roG);  %% characteristic inertial pressure scale velocity
u_tau = sqrt(tau_i/roG);  %% gas-side interfacial friction velocity
Re_g = roG*u_g*H/muG;  %% grvitational Reynolds number
Re_p = roG*u_p*H/muG;  %% pressure Reynolds number
Re_tau = roG*u_tau*H/muG;  %% interfacial friction Reynolds number
We = H*roG*u_p^2/sigma;  %% Weber number
Fr = Re_p/Re_g;  %% Froude number

% calculate normalized U
zL = linspace(-delta,0,n/2);
zG = linspace(0,dG,n/2+1); zG = zG(2:end);
zz = [zL, zG];
dz = zz(2)-zz(1);
aL = 1/m*(0.5*Re_p*(1-r*(Re_g/Re_p)^2));
bL = -1/m*(Re_tau^2/Re_p);
cL = -1/m*(0.5*Re_p*(1-r*(Re_g/Re_p)^2)*delta^2 + (Re_tau^2/Re_p)*delta);
UL = aL*zL.^2 + bL*zL + cL*ones(1,n/2);
aG = 0.5*Re_p*(1-(Re_g/Re_p)^2);
bG = -Re_tau^2/Re_p;
cG = UL(end);
UG = aG*zG.^2 + bG*zG + cG*ones(1,n/2);
U = -[UL UG];

% define and plot pertrubation
alpha = linspace(0,2,n+1); alpha = alpha(2:end);

%% construct A and B matrices
figure(1)
FS = 'fontsize'; MS = 'markersize';
eps = 10e-5;
Re_p = 2000;
alpha = linspace(0,2,n+1); alpha = alpha(2:end);
for j = 1:length(alpha)
    % construct A and B
    A = chebop(-delta,dG);
    B = chebop(-delta,dG);
    % Orr-Sommerfeld
    A.op = @(y,psiL,psiG) [(m*(beta(1)^4*diff(psiL,4)-2*beta(1)^2*al(j)^2*diff(psiL,2)+al(j)^4*psiL)/(r*Re_p)+2i*aL*al(j)*psiL...
                           -1i*al(j)*(aL*((y+delta)/beta(1)).^2+bL*(y+delta)/beta(1)+cL).*(beta(1)^2*diff(psiL,2)-al(j)^2*psiL));
                           ((beta(2)^4*diff(psiG,4)-2*beta(2)^2*al(j)^2*diff(psiG,2)+al(j)^4*psiG)/Re_p+2i*aG*al(j)*psiG...
                           -1i*al(j)*(aG*((y+delta)/beta(2)).^2+bG*(y+delta)/beta(2)+cG).*(beta(2)^2*diff(psiG,2)-al(j)^2*psiG))];
    B.op = @(y,psiL,psiG) [(beta(1)^2*diff(psiL,2) - al(j)^2*psiL) ; (beta(2)^2*diff(psiG,2)-al(j)^2*psiG)];
    % apply BCs
    A.lbc = @(psiL,psiG) [(psiL - psiG); % BC 5
                         ((cG*(beta(2)*diff(psiG) - beta(1)*diff(psiL))) -(bG-bL)*psiL); % BC 6
                         (cG*(beta(2)^2*diff(psiG,2) - m*beta(1)^2*diff(psiL,2) + al(j)^2*(psiG-m*psiL)) - 2*(aG-m*aL)*psiL); % BC 7
                         (1i*al(j)*Re_p*dummy*(cG*(r*beta(1)*diff(psiL) - beta(2)*diff(psiG)) + bG*psiG - r*bL*psiL...
                         + r*al(j)^2*(beta(1)*diff(psiL) - beta(2)*diff(psiG))/(We*(bG-bL)+dummy2))...
                         + beta(2)^3*diff(psiG,3) - 3*beta(2)*al(j)^2*diff(psiG) - m*(beta(1)^3*diff(psiL,3) - 3*beta(1)*al(j)^2*diff(psiL)))]; % BC 8
    A.rbc = @(psiL,psiG) [psiL; beta(1)*diff(psiL); psiG; beta(2)*diff(psiG)]; % BC 1-4
    B.lbc = @(psiL,psiG) [(psiL - psiG); % BC 5
                         1/(1i*al(j))*(-beta(1)*diff(psiL) + beta(2)*diff(psiG)); % BC 6
                         1/(1i*al(j))*((beta(2)^2*diff(psiG,2)+al(j)^2*psiG) - m*(beta(1)^2*diff(psiL,2)+al(j)^2*psiL)); % BC 7
                         Re_p*(r*beta(1)*diff(psiL) - beta(2)*diff(psiG))];  % BC 8
    % calculate and plot eigen values
    tic
    w = eigs(A,B,50); 
%     w = eigs(A,B,50,'LR');
    toc
    maxw = max(real(w));
    drawnow
    plot(w,'.r',MS,16), grid on, axis square
    title(sprintf('Re = %8.2f   \\omega_r = %7.5f',Re_p,maxw),FS,16)
end